@@ -1,14 +1,15 @@
 """
-``keybinder`` is a python module for gtk-based applications
-registering global key bindings.
+``keybinder`` is a python module for registering global key bindings,
+for gtk-based applications.
 
-This module originates in `Tomboy`_ as has been widely reused without
-having a separate release. This package has taken the python bindings
+This module originates in `Tomboy`_ and has been widely reused without
+having a separate release. This package has taken the python module
 for Tomboy's keybinder from the `Deskbar Applet`_ project, and broken
-it out to be a standalone module.
+it out to a standalone module.
 
 The module is licenced under the GNU General Public License v2 (or at
-your option, any later version).
+your option, any later version), see the included file COPYING for
+details.
 
 .. _Tomboy:            http://projects.gnome.org/tomboy/
 .. _`Deskbar Applet`:  http://projects.gnome.org/deskbar-applet/
@@ -16,7 +17,7 @@ your option, any later version).
 Homepage: http://kaizer.se/wiki/python-keybinder/
 """
 
-__version__ = "0.0.3"
+__version__ = "0.0.4"
 
 # gtk has to be setup
 # this is to avoid warning spew if you plainly
